@@ -51,6 +51,7 @@ FwupdRemote	*fwupd_remote_new			(void);
 const gchar	*fwupd_remote_get_id			(FwupdRemote	*self);
 const gchar	*fwupd_remote_get_title			(FwupdRemote	*self);
 const gchar	*fwupd_remote_get_agreement		(FwupdRemote	*self);
+const gchar	*fwupd_remote_get_remotes_dir		(FwupdRemote	*self);
 const gchar	*fwupd_remote_get_checksum		(FwupdRemote	*self);
 const gchar	*fwupd_remote_get_username		(FwupdRemote	*self);
 const gchar	*fwupd_remote_get_password		(FwupdRemote	*self);
@@ -71,4 +72,7 @@ gchar		*fwupd_remote_build_firmware_uri	(FwupdRemote	*self,
 							 const gchar	*url,
 							 GError		**error);
 
+FwupdRemote	*fwupd_remote_from_variant		(GVariant	*value);
+GPtrArray	*fwupd_remote_array_from_variant	(GVariant	*value);
+
 G_END_DECLS
